pilas.habilidades.Imitar

Package pilas :: Module habilidades :: Class Imitar |
[hide private]
[frames] | no frames]

# Class Imitar

source code

    object --+
             |
     Habilidad --+
                 |
                Imitar

Logra que el actor imite las propiedades de otro.

Instance Methods | [hide private]
__init__(self, receptor, objeto_a_imitar, con_rotacion=True) Inicializa la habilidad. | source code
actualizar(self) | source code
eliminar(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor, objeto_a_imitar, con_rotacion=True) (Constructor) | source code
Inicializa la habilidad. :param receptor: Referencia al actor. :param objeto_a_imitar: Cualquier objeto con atributos rotacion, x e y (por ejemplo otro actor). :param con_rotacion: Si debe imitar o no la rotación. Overrides: object.__init__

### actualizar(self) | source code
Overrides: Habilidad.actualizar

### eliminar(self) | source code
Overrides: Habilidad.eliminar